# 구성

## 런타임 매개변수

- `host`
-`port`
-`workers`

## 환경 변수

-`VYRO_ENV`
-`VYRO_SECRET_KEY`
-`VYRO_WORKERS`
-`VYRO_LOG_SAMPLE_INFO`
-`VYRO_LOG_SAMPLE_WARN`
- `VYRO_LOG_SAMPLE_ERROR`

생산 준비 상태 확인을 위해 CI에서 `vyro doctor --strict`를 사용하세요.